lgammaf
产品支持情况
- Ascend 950PR/Ascend 950DT:支持
- Atlas A3 训练系列产品/Atlas A3 推理系列产品:不支持
- Atlas A2 训练系列产品/Atlas A2 推理系列产品:不支持
- Atlas 200I/500 A2 推理产品:不支持
- Atlas 推理系列产品AI Core:不支持
- Atlas 推理系列产品Vector Core:不支持
- Atlas 训练系列产品:不支持
功能说明
获取输入数据x伽马值的绝对值并求自然对数。

函数原型
C++
inline float lgammaf(float x)
参数说明
表1 参数说明
| 参数名 | 输入/输出 | 描述 |
|---|---|---|
| x | 输入 | 源操作数。 |
返回值说明
输入数据的伽马值的绝对值并求自然对数。
- 当x为0时,返回值为inf。
- 当x为inf时,返回值为inf。
- 当x为-inf时,返回值为inf。
- 当x为nan时,返回值为nan。
- 若返回值超出float最大范围,返回值为inf。
- 若返回值超出float最小范围,返回值为-inf。
约束说明
无
需要包含的头文件
使用该接口需要包含"simt_api/math_functions.h"头文件。
C++
#include "simt_api/math_functions.h"
调用示例
SIMT编程场景:
C++__global__ __launch_bounds__(256) void compute_lgammaf(float *result, const float *x, uint32_t count) { const uint32_t idx = blockIdx.x * blockDim.x + threadIdx.x; if (idx >= count) { return; } result[idx] = lgammaf(x[idx]); }SIMD与SIMT混合编程场景:
C++__simt_vf__ __launch_bounds__(256) inline void compute_lgammaf_vf(__gm__ float *result, __gm__ const float *x, uint32_t count) { const uint32_t idx = blockIdx.x * blockDim.x + threadIdx.x; if (idx >= count) { return; } result[idx] = lgammaf(x[idx]); } __global__ __vector__ void run_lgammaf(__gm__ float *result, __gm__ const float *x, uint32_t count) { asc_vf_call<compute_lgammaf_vf>(dim3(256), result, x, count); }
输入输出示例如下:
Text
x:0.25, 0.75, 1.25, 1.75
result: 1.288023 0.203281 -0.09827184 -0.08440112